@@ -30,7 +30,7 @@ Well, here? nothing, all the work is done in the superclass.
 
 =head1 AUTHOR
 
-Daniel Ruoso <daniel.ruoso@verticalone.pt>
+Daniel Ruoso <daniel@ruoso.com>
 
 =head1 BUG REPORTS
 
